@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use DateTime;
 use DateTime::Locale;
@@ -46,7 +46,7 @@ sub new {
   }, $class;
 
   $self->time_zone( $config{time_zone} || delete $config{timezone} || 'UTC' );
-  $self->locale( $config{locale} || 'en_us' );
+  $self->locale( $config{locale} || 'en-US' );
 
   $self;
 }
@@ -89,7 +89,7 @@ sub locale {
 
   if ( $locale ) {
     $self->{config}->{locale} =
-      ( blessed $locale && $locale->isa('DateTime::Locale::root') ) 
+      ( blessed $locale && ($locale->isa('DateTime::Locale::root') || $locale->isa('DateTime::Locale::FromData') ) ) 
         ? $locale
         : DateTime::Locale->load( $locale );
   }
